/*
  Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Library General Public
  License version 2 as published by the Free Software Foundation.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Library General Public License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to
  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  Boston, MA 02110-1301, USA.
*/

#include "annotationresourcemodel.h"
#include "pimo.h"

#include <Soprano/Vocabulary/NAO>
#include <Nepomuk/Tag>
#include <Nepomuk/Variant>

#include <QtCore/QMimeData>

#include <KPassivePopup>
#include <KLocale>
#include <KDebug>
#include <KUrl>


AnnotationResourceModel::AnnotationResourceModel( QObject* parent )
    : SimpleResourceModel( parent )
{
}


AnnotationResourceModel::~AnnotationResourceModel()
{
}


QStringList AnnotationResourceModel::mimeTypes() const
{
    kDebug();
    return KUrl::List::mimeDataTypes();
}


Qt::ItemFlags AnnotationResourceModel::flags( const QModelIndex& index ) const
{
    if ( index.isValid() ) {
        return SimpleResourceModel::flags( index )|Qt::ItemIsDropEnabled;
    }
    else {
        return SimpleResourceModel::flags( index );
    }
}


bool AnnotationResourceModel::dropMimeData( const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent )
{
    kDebug();
    if( parent.isValid() && KUrl::List::canDecode( data ) ) {
        KUrl::List uris = KUrl::List::fromMimeData( data );

        Nepomuk::Resource annotationResource = resourceForIndex( parent );

        foreach( const KUrl& uri, uris ) {
            Nepomuk::Resource resource( uri );
            if( annotationResource.hasType( Soprano::Vocabulary::NAO::Tag() ) ) {
                resource.addTag( annotationResource );
            }
            else if( annotationResource.hasType( Nepomuk::Vocabulary::PIMO::Location() ) ) {
                QList<Nepomuk::Resource> annotations = resource.property( Nepomuk::Vocabulary::PIMO::hasLocation() ).toResourceList();
                if( !annotations.contains( annotationResource ) ) {
                    annotations.append( annotationResource );
                    resource.setProperty( Nepomuk::Vocabulary::PIMO::hasLocation(), annotations );
                }
            }
            else { // contact
                QList<Nepomuk::Resource> annotations = resource.property( Nepomuk::Vocabulary::PIMO::isRelated() ).toResourceList();
                if( !annotations.contains( annotationResource ) ) {
                    annotations.append( annotationResource );
                    resource.setProperty( Nepomuk::Vocabulary::PIMO::isRelated(), annotations);
                }
            }

            KPassivePopup::message( i18n("Nepoid"),
                                    i18n("Annotated %1 with %2.",
                                         resource.resourceUri().toString(),
                                         annotationResource.resourceUri().toString()),
                                    (QWidget*)0 );
        }

        kDebug() << "done";

        return true;
    }
    else {
        kDebug() << "no urls";
        return false;
    }
}

#include "annotationresourcemodel.moc"
