/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include <QtCore/QVariant>
#include <Nepomuk/Types/Property>
#include <KServiceTypeTrader>
#include <KService>

#include "annotationpluginfactory.h"
#include "annotationplugin.h"

// Singleton initialization
Nepomuk::AnnotationPluginFactory* Nepomuk::AnnotationPluginFactory::m_instance = 0;

Nepomuk::AnnotationPluginFactory* Nepomuk::AnnotationPluginFactory::instance()
{
	if(!m_instance) {
		m_instance = new AnnotationPluginFactory();
		m_instance->setParent(qApp);
	}

	return m_instance;
}

QList<Nepomuk::AnnotationPlugin*> Nepomuk::AnnotationPluginFactory::getPluginsForProperty(const Nepomuk::Types::Property& property)
{
	QList<AnnotationPlugin*> plugins;
	if(!property.isValid())
		return plugins;

	// Note : There's one service file for one library, but a single service file can contain several properties
	KService::List services = KServiceTypeTrader::self()->query("Nepomuk/AnnotationPlugin", QString("'%1' in [X-KDE-NepomukProperties]").arg(property.uri().toString()));

	foreach(const KSharedPtr<KService>& service, services)
		// Return the cached instance if we have one, create a new one else
		plugins.append(getPluginInstance(service));

	return plugins;
}

QList<Nepomuk::AnnotationPlugin*> Nepomuk::AnnotationPluginFactory::getPluginsForType(const QUrl& rdfType)
{
	QList<AnnotationPlugin*> plugins;

	// Note : There's one service file for one library, but a single service file can contain several properties
	KService::List services = KServiceTypeTrader::self()->query("Nepomuk/AnnotationPlugin", QString("'%1' in [X-KDE-NepomukResourceType]").arg(rdfType.toString()));

	foreach(const KSharedPtr<KService>& service, services)
		// Return the cached instance if we have one, create a new one else
		plugins.append(getPluginInstance(service));

	return plugins;
}

QList<Nepomuk::AnnotationPlugin*> Nepomuk::AnnotationPluginFactory::getAllPlugins()
{
	QList<AnnotationPlugin*> plugins;

	KService::List services = KServiceTypeTrader::self()->query("Nepomuk/AnnotationPlugin");

	foreach(const KSharedPtr<KService>& service, services)
		plugins.append(getPluginInstance(service));

	return plugins;
}

Nepomuk::AnnotationPluginFactory::AnnotationPluginFactory(QObject* parent) : QObject(parent)
{
	// Create the base plugin
	m_cachedPlugins.insert("nepomuk_annotationplugin", new AnnotationPlugin(this));
}

Nepomuk::AnnotationPlugin* Nepomuk::AnnotationPluginFactory::getPluginInstance(const KSharedPtr<KService>& service)
{
	if(m_cachedPlugins.contains(service->library())) {
		return m_cachedPlugins.value(service->library());
	} else {
		AnnotationPlugin* plugin = service->createInstance<AnnotationPlugin>(this, QVariantList(), 0);
		if(!plugin) {
			qDebug() << "Error, cannot instantiate plugin from library" << service->library();
		} else {
			m_cachedPlugins.insert(service->library(), plugin);
			return plugin;
		}
	}
	return NULL;
}

#include "annotationpluginfactory.moc"

