/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "annotationproperty.h"
#include "annotationplugin.h"

using namespace Nepomuk;

class AnnotationProperty::Private : public QSharedData
{
public:
	int relevance;
	Nepomuk::Types::Property property;
	Nepomuk::AnnotationPlugin* parent;
	QString label;
	QString description;
	QPixmap icon;
};

AnnotationProperty::AnnotationProperty(Nepomuk::AnnotationPlugin* parent) : d(new Private)
{
	d->parent = parent;
}

AnnotationProperty::AnnotationProperty(Nepomuk::AnnotationPlugin* parent, const Nepomuk::Types::Property& property, int relevance, const QPixmap& icon) : d(new Private)
{
	Nepomuk::Types::Property p = property; // DEBUG : hack to cast away the const
	d->parent = parent;
	d->property = property;
	d->relevance = relevance;
	d->icon = icon;
	d->label = p.label();
	d->description = p.comment();
}

AnnotationProperty::AnnotationProperty(Nepomuk::AnnotationPlugin* parent, const QUrl& uri, int relevance, const QPixmap& icon) : d(new Private)
{
	d->parent = parent;
	d->property = Nepomuk::Types::Property(uri);
	d->label = d->property.label();
	d->description = d->property.comment();
	d->relevance = relevance;
	d->icon = icon;
}
AnnotationProperty::AnnotationProperty(const AnnotationProperty& other) : d(new Private)
{
	d->parent = other.parent();
	d->property = other.property();
	d->relevance = other.relevance();
	d->parent = other.parent();
	d->icon = other.icon();
	d->label = other.label();
	d->description = other.description();
}

AnnotationProperty& AnnotationProperty::operator=(const AnnotationProperty& other)
{
	d->parent = other.parent();
	d->property = other.property();
	d->relevance = other.relevance();
	d->parent = other.parent();
	d->icon = other.icon();
	d->label = other.property().label();
	d->description = other.property().comment();
	return *this;
}

AnnotationProperty::~AnnotationProperty()
{
}

Nepomuk::Types::Property AnnotationProperty::property() const
{
	return d->property;
}

QString AnnotationProperty::label() const
{
	return d->label;
}

void AnnotationProperty::setLabel(const QString& label)
{
	d->label = label;
}

QString AnnotationProperty::description() const
{
	return d->description;
}

void AnnotationProperty::setDescription(const QString& description)
{
	d->description = description;
}

int AnnotationProperty::relevance() const
{
	return d->relevance;
}

QPixmap AnnotationProperty::icon() const
{
	return d->icon;
}

Nepomuk::AnnotationPlugin* AnnotationProperty::parent() const
{
	return d->parent;
}

