/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "annotationresource.h"
#include "annotationplugin.h"

#include <Nepomuk/Resource>

using namespace Nepomuk;

class AnnotationResource::Private : public QSharedData {
public:
	QString label;
	QString description;
	Nepomuk::Resource resource;
	QVariant icon; // Either the icon name or a QImage
	AnnotationPlugin* parent;
};

AnnotationResource::AnnotationResource(AnnotationPlugin* parent) : d(new Private)
{
	d->parent = parent;
}

AnnotationResource::AnnotationResource(AnnotationPlugin* parent, const Resource& resource, const QString& label, const QString& description, const QVariant& icon) : d(new Private)
{
	d->parent = parent;
	d->resource = resource;
	d->label = label;
	d->description = description;
	d->icon = icon;
}

AnnotationResource::AnnotationResource(const AnnotationResource& other) : d(new Private)
{
	d->parent = other.parent();
	d->resource = other.resource();
	d->label = other.label();
	d->description = other.description();
	d->icon = other.icon();
	d->parent = other.parent();
}

AnnotationResource& AnnotationResource::operator=(const AnnotationResource& other)
{
	d->parent = other.parent();
	d->resource = other.resource();
	d->label = other.label();
	d->description = other.description();
	d->icon = other.icon();
	d->parent = other.parent();
	return *this;
}

AnnotationResource::~AnnotationResource()
{
}

QString AnnotationResource::label() const
{
	return d->label;
}

void AnnotationResource::setLabel(const QString& label)
{
	d->label = label;
}

QString AnnotationResource::description() const
{
	return d->description;
}

void AnnotationResource::setDescription(const QString& description)
{
	d->description = description;
}

QVariant AnnotationResource::icon() const
{
	return d->icon;
}

void AnnotationResource::setIcon(const QVariant& icon)
{
	d->icon = icon;
}

Resource AnnotationResource::resource() const
{
	return d->resource;
}

AnnotationPlugin* AnnotationResource::parent() const
{
	return d->parent;
}

bool AnnotationResource::operator==(const AnnotationResource& other) const
{
	return resource() == other.resource();
}
