/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef ANNOTATIONRESOURCE_H
#define ANNOTATIONRESOURCE_H

#include <QtCore>
#include <QtGui/QPixmap>
#include <QtGui/QImage>
#include <nepomuk/nepomuk_export.h>

namespace Nepomuk {

class Resource;
class AnnotationPlugin;

/**
 * \class AnnotationResource annotationresource.h AnnotationResource
 * \brief This class describes a Nepomuk at a higher level than Nepomuk::Resource . A
 * single AnnotationResource can be described by several Nepomuk::Resource objects, but is
 * identified by one single Nepomuk::Resource.
 *
 * This class uses a shared data implementation.
 *
 * \author Adrien Bustany <madcat@mymadcat.com>
 */
class NEPOMUK_EXPORT AnnotationResource
{

public:
	/**
	 * Creates an empty AnnotationResource
	 */
	AnnotationResource(AnnotationPlugin* parent = 0);

	/**
	 * Creates an AnnotationResource and fills it with the given data
	 */
	AnnotationResource(AnnotationPlugin* parent, const Resource& resource, const QString& label, const QString& description = QString(), const QVariant& icon = QString());
	AnnotationResource(const AnnotationResource& other);
	AnnotationResource& operator=(const AnnotationResource& other);
	~AnnotationResource();

	QString label() const;
	void setLabel(const QString& label);

	QString description() const;
	void setDescription(const QString& description);

	/**
	 * Returns a variant which can either be the icon name, or a QImage
	 */
	QVariant icon() const;
	void setIcon(const QVariant& icon);

	Resource resource() const;
	AnnotationPlugin* parent() const;

	bool operator==(const AnnotationResource& other) const;

private:
	class Private;
	QSharedDataPointer<Private> d;
};

} // End namespace Nepomuk

#endif
