#include "annotationresult.h"
#include "annotationplugin.h"

using namespace Nepomuk;

class AnnotationResult::Private {
public:
	Private()
	{
		parentResult = NULL;
		ready = false;
	}
	AnnotationResult* parentResult;

	QList<AnnotationResource> resources;
	bool ready;
};

AnnotationResult::AnnotationResult(AnnotationPlugin* parent) : QObject(parent), d(new Private)
{
}

AnnotationResult::~AnnotationResult()
{
	delete d;
}

bool AnnotationResult::isReady() const
{
	return d->ready;
}

void AnnotationResult::emitStatus()
{
	if(d->ready)
		setReady();
}

AnnotationPlugin* AnnotationResult::parentPlugin()
{
	if(d->parentResult) {
		return d->parentResult->parentPlugin();
	} else {
		return qobject_cast<AnnotationPlugin*>(QObject::parent());
	}
}

const QList<AnnotationResource>& AnnotationResult::resources()
{
	return d->resources;
}

void AnnotationResult::setResources(const QList<AnnotationResource>& resources)
{
	if(d->parentResult) {
		d->parentResult->setResources(resources);
	} else {
		d->resources = resources;
	}
}

void AnnotationResult::setReady()
{
	if(d->parentResult) {
		d->parentResult->setReady();
	} else {
		d->ready = true;
		emit ready();
	}
}

void AnnotationResult::setParentResult(AnnotationResult* parent)
{
	d->parentResult = parent;

	// Reparent the result, so that it'll be destroyed with its parent
	setParent(parent);

	// Handle the case where setParentResult occurs after the result get its resources set
	if(isReady()) {
		parent->setResources(d->resources);
		parent->setReady();
	}
}

#include "annotationresult.moc"
