/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef ANNOTATIONPLUGIN_NCO_H
#define ANNOTATIONPLUGIN_NCO_H

#include "annotationplugin.h"
#include "annotationproperty.h"

#include <soprano/soprano.h>
#include <KPluginFactory>
#include <KPluginLoader>

namespace Soprano {
	namespace Util {
		class AsyncModel;
		class AsyncResult;
	}
}

namespace Nepomuk {

class AnnotationResource;
class AnnotationResult;
class NepomukProxy;

class NcoAnnotationPlugin : public AnnotationPlugin
{
	Q_OBJECT

public:
	NcoAnnotationPlugin(QObject* parent, const QList<QVariant>&);
	~NcoAnnotationPlugin();
	bool isReady() const;

	QString name() const;
	QString iconName() const;

public Q_SLOTS:
	AnnotationResult* getResources(const QString& filter);
	AnnotationResult* getResources(const QString& filter, const Types::Property& property, const Soprano::Node& object);
	AnnotationResult* getResource(const QUrl& resourceUri);
	AnnotationResult* getResourcesRelatedTo(const QUrl& resourceUri);
	virtual QList<AnnotationProperty> getProperties(const QString& mimetype);
	virtual QList<AnnotationProperty> getProperties(const QUrl& rdfType);
	virtual void addRelation(const Types::Property& property, const QUrl& subject, const Soprano::Node& object);
	virtual void addRelation(const AnnotationProperty& property, const QUrl& subject, const Soprano::Node& object);

private Q_SLOTS:
	void contacts_cb(const QList<Soprano::BindingSet>& results);
	void contacts_with_property_cb(Soprano::Util::AsyncResult* result);
	void contacts_relatedTo_cb(Soprano::Util::AsyncResult* result);

private:
	NepomukProxy* m_nepomuk;
	QList<AnnotationResource> m_resources;
	/**
	 * returns the index from the item in items with the given uri, or -1 if not found
	 */
	int indexFromUri(const QList<AnnotationResource>& list, const QUrl& uri);


	AnnotationProperty m_regionDepicts;

	Soprano::Util::AsyncModel* m_soprano;

	// Used for queries with properties, since we need first to fetch the
	// results and then to filter the results
	QMap<Soprano::Util::AsyncResult*, QString> m_queryFilters;

	// Maps the Soprano results to the plugin results (to know which result is ready on a Soprano callback)
	QMap<Soprano::Util::AsyncResult*, AnnotationResult*> m_resultsTable;

	bool m_ready;
};

} // End namespace Nepomuk

K_PLUGIN_FACTORY(NcoAnnotationPluginFactory, registerPlugin<Nepomuk::NcoAnnotationPlugin>();)
K_EXPORT_PLUGIN(NcoAnnotationPluginFactory("nepomuk_ncoannotationplugin"))

#endif
