#include <KApplication>
#include <KCmdLineArgs>
#include <KAboutData>
#include <KRun>

#include "annotationpluginfactory.h"
#include "annotationplugin.h"
#include "syncannotationplugin.h"
#include "annotationresource.h"
#include "annotationresult.h"

#define PIMODOCUMENT "http://www.semanticdesktop.org/ontologies/2007/11/01/pimo#Document"

int main(int argc, char **argv)
{
	KAboutData aboutData("pimodocument-runner",
                         0,
                         ki18n("PIMO Document runner"),
                         "0.1",
                         ki18n("Run PIMO Document resources"),
                         KAboutData::License_GPL,
                         ki18n("Adrien Bustany"),
                         KLocalizedString());
	aboutData.setProgramIconName("nepomuk");
	KCmdLineArgs::init(argc, argv, &aboutData);

	KCmdLineOptions options;
	options.add("+uri", ki18n("The uri to run"));
	KCmdLineArgs::addCmdLineOptions(options);

	KApplication app;

	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
	if(args->count() != 1) {
		qDebug() << "Usage :" << args->appName() << "uri";
		return 1;
	}

	Nepomuk::AnnotationPlugin* plugin = Nepomuk::AnnotationPluginFactory::instance()->getPluginsForType(QUrl::fromEncoded(PIMODOCUMENT, QUrl::StrictMode)).first();
	Nepomuk::SyncAnnotationPlugin* syncPlugin = new Nepomuk::SyncAnnotationPlugin(plugin);

	Nepomuk::AnnotationResult* result = syncPlugin->getResource(QUrl(args->arg(0)));
	if(result->resources().empty()) {
		qDebug() << "Error, the given resource is not a PIMO Document";
		return 1;
	}

	Nepomuk::AnnotationResource groundingResource = result->resources().first();
	QString groundingUrl = ( groundingResource.description() == QString() ? groundingResource.label() : groundingResource.description() );

	qDebug() << "url to run : " << groundingUrl;
	KRun* run = new KRun(groundingUrl, NULL);
	QObject::connect(run, SIGNAL(finished()), &app, SLOT(quit()));

	args->clear();
	return app.exec();
}
