/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "syncannotationplugin.h"
#include "annotationresource.h"
#include "annotationresult.h"

using namespace Nepomuk;

class SyncAnnotationPlugin::Private
{
	public:
		AnnotationPlugin *plugin;
		QMutex mutex;
};

QString SyncAnnotationPlugin::name() const
{
	return d->plugin->name();
}

QString SyncAnnotationPlugin::iconName() const
{
	return d->plugin->iconName();
}

SyncAnnotationPlugin::SyncAnnotationPlugin(AnnotationPlugin* plugin) : QObject(plugin), d(new Private)
{
	d->plugin = plugin;
	qRegisterMetaType<QList<Nepomuk::AnnotationResource> >("QList<Nepomuk::AnnotationResource>");
}

SyncAnnotationPlugin::~SyncAnnotationPlugin()
{
	delete d;
}

AnnotationResult* SyncAnnotationPlugin::getResources(const QString& filter)
{
	QMutexLocker(&d->mutex);
	AnnotationResult* result = d->plugin->getResources(filter);
	if(result->isReady()) {
		return result;
	} else {
		QEventLoop waitLoop;
		connect(result, SIGNAL(ready()), &waitLoop, SLOT(quit()));
		waitLoop.exec();
	}
	return result;
}

AnnotationResult* SyncAnnotationPlugin::getResources(const QString& filter, const Types::Property& property, const Soprano::Node& object)
{
	QMutexLocker(&d->mutex);
	AnnotationResult* result = d->plugin->getResources(filter, property, object);
	if(result->isReady()) {
		return result;
	} else {
		QEventLoop waitLoop;
		connect(result, SIGNAL(ready()), &waitLoop, SLOT(quit()));
		waitLoop.exec();
	}
	return result;
}

AnnotationResult* SyncAnnotationPlugin::getResource(const QUrl& resourceUri)
{
	QMutexLocker(&d->mutex);
	AnnotationResult* result = d->plugin->getResource(resourceUri);
	if(result->isReady()) {
		return result;
	} else {
		QEventLoop waitLoop;
		connect(result, SIGNAL(ready()), &waitLoop, SLOT(quit()));
		waitLoop.exec();
	}
	return result;
}

QList<AnnotationProperty> SyncAnnotationPlugin::getProperties(const QString& mimetype)
{
	return d->plugin->getProperties(mimetype);
}

QList<AnnotationProperty> SyncAnnotationPlugin::getProperties(const QUrl& rdfType)
{
	return d->plugin->getProperties(rdfType);
}

void SyncAnnotationPlugin::addRelation(const Types::Property& property, const QUrl& subject, const Soprano::Node& object)
{
	d->plugin->addRelation(property, subject, object);
}

void SyncAnnotationPlugin::addRelation(const AnnotationProperty& property, const QUrl& subject, const Soprano::Node& object)
{
	d->plugin->addRelation(property, subject, object);
}

