/*
 *
 * $Id: sourceheader 511311 2006-02-19 14:51:05Z trueg $
 *
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2006-2007 Sebastian Trueg <trueg@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * See the file "COPYING" for the exact licensing terms.
 */

#include "mainwindow.h"
#include "searchhitmodel.h"
#include "queryserviceclient.h"

#include <nepomuk/resourcemanager.h>

#include <KDebug>
#include <KRun>
#include <KComboBox>

#include <QtCore/QCoreApplication>
#include <QtCore/QRegExp>
#include <QtGui/QAbstractItemView>
#include <QtGui/QSortFilterProxyModel>

Q_DECLARE_METATYPE( Nepomuk::Search::Result )

using namespace Soprano;


MainWindow::MainWindow()
  : QMainWindow(),
    Ui::MainWindow()
{
    setupUi( this );

    Nepomuk::ResourceManager::instance()->init();

    m_searchClient = new Nepomuk::Search::QueryServiceClient( this );

    m_searchCompletion = m_editSearchText->completionObject();

    connect( m_buttonSearch, SIGNAL( clicked() ),
             this, SLOT( slotSearch() ) );
    connect( m_editSearchText, SIGNAL( returnPressed() ),
             this, SLOT( slotSearch() ) );
    connect( m_searchClient, SIGNAL( newEntries( const QList<Nepomuk::Search::Result>& ) ),
             m_resultsView, SLOT( updateResources( const QList<Nepomuk::Search::Result>& ) ) );
    connect( m_resultsView, SIGNAL( resourceActivated( const QUrl& ) ),
             this, SLOT( slotResourceActivated( const QUrl& ) ) );
}


MainWindow::~MainWindow()
{
}


void MainWindow::slotSearch()
{
    QString searchText = m_editSearchText->text();

    m_resultsView->clear();

    if ( !searchText.isEmpty() ) {
        m_searchCompletion->addItem( searchText );

        kDebug() << "Searching for" << searchText;

        m_searchClient->query( searchText );
    }
}


void MainWindow::slotResourceActivated( const QUrl& uri )
{
    if ( uri.isValid() ) {
        // FIXME: Use a plugin-system like the painting one for execution of resources (maybe integrate it into the gui item)
        new KRun( uri, this );
    }
}

#include "mainwindow.moc"
