/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef NEPOMUKMENUPLUGIN_H
#define NEPOMUKMENUPLUGIN_H

#include <konq_popupmenu.h>
#include <konq_popupmenuplugin.h>
#include <QtCore>
#include <QtGui/QMenu>
#include <KPluginFactory>
#include <KPluginLoader>
#include <nepomuk/resource.h>

class QWidgetAction;
class KRatingWidget;
class KHTMLView;

namespace Soprano {
	class BindingSet;
	namespace Util {
		class AsyncModel;
		class AsyncResult;
	}
}

class NepomukMenuPlugin : public KonqPopupMenuPlugin
{

	Q_OBJECT

public:
	NepomukMenuPlugin(QObject* parent, const QVariantList& args);
	~NepomukMenuPlugin();
	// Called on every right click
	virtual void setup(KActionCollection* collection, const KonqPopupMenuInformation& info, QMenu* menu);

private:
	// Access to Soprano
	Soprano::Util::AsyncModel* m_soprano;

	// Rating part
	QWidgetAction* m_rateAction;
	KRatingWidget* m_ratingWidget;
	QUrl m_currentUri;

	// Tagging part
	// Maps the action to the (resource url, hasTag) pair
	QHash<KAction*, QUrl> m_actionUrl;
	// Maps the action to its current state, to avoid unnecessary writes in Nepomuk
	QHash<KAction*, bool> m_actionChecked;
	KAction* m_addTagAction;

	Nepomuk::Resource m_pimoResource;

	// Saves the current page into Nepomuk (pimo:Document and nfo:Website). Returns the pimo:Webpage resource.
	Nepomuk::Resource saveCurrentPage();

	KHTMLView* m_view;

private Q_SLOTS:
	void fillMenu(Soprano::Util::AsyncResult*); // Fills the menu with the information already in Nepomuk
	void ratingChanged(unsigned int rating);
	void tagCallback();
	void addNewTag();

};

K_PLUGIN_FACTORY(NepomukMenuPluginFactory, registerPlugin<NepomukMenuPlugin>();)
K_EXPORT_PLUGIN(NepomukMenuPluginFactory("nepomukmenuplugin"))

#endif
