/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "nepomukrunner.h"

#include "annotationpluginfactory.h"
#include "syncannotationplugin.h"
#include "annotationresource.h"
#include "annotationresult.h"

#include <Nepomuk/Resource>
#include <Plasma/QueryMatch>

#include <KIcon>
#include <klocalizedstring.h>
#include <KRun>

using namespace Nepomuk;

class NepomukRunner::Private
{
	public:
		QList<SyncAnnotationPlugin*> plugins;
};

NepomukRunner::NepomukRunner(QObject* parent, const QVariantList& args) : AbstractRunner(parent, args), d(new Private)
{
	AnnotationPluginFactory* factory = AnnotationPluginFactory::instance();

	foreach(AnnotationPlugin* p, factory->getAllPlugins()) {
		d->plugins.append(new SyncAnnotationPlugin(p));
	}
}

NepomukRunner::NepomukRunner(QObject* parent, const QString& serviceId) : AbstractRunner(parent, serviceId)
{
}

NepomukRunner::~NepomukRunner()
{
	delete d;
}

void NepomukRunner::createRunOptions(QWidget* widget)
{
}

void NepomukRunner::match(Plasma::RunnerContext& context)
{
	QList<Plasma::QueryMatch> matches;

	foreach(SyncAnnotationPlugin* p, d->plugins) {
		Nepomuk::AnnotationResult* r = p->getResources(context.query());
		QList<AnnotationResource> res = r->resources();
		delete r;

		foreach(const AnnotationResource& r, res) {
			Plasma::QueryMatch::Type type = Plasma::QueryMatch::NoMatch;
			qreal relevance = 0;

			if(r.label() == context.query()) {
				relevance = 1;
				type = Plasma::QueryMatch::ExactMatch;
			} else if (r.label().contains(context.query(), Qt::CaseInsensitive)) {
				relevance = 0.7;
				type = Plasma::QueryMatch::PossibleMatch;
			} else if (r.description().contains(context.query(), Qt::CaseInsensitive)) {
				relevance = 0.5;
				type = Plasma::QueryMatch::PossibleMatch;
			}

			if(type != Plasma::QueryMatch::NoMatch) {
				Plasma::QueryMatch match(this);
				match.setType(type);
				match.setRelevance(relevance);
				KIcon icon;
				switch(r.icon().type()) {
					case QVariant::String:
						icon = KIcon(r.icon().toString());
						break;
					case QVariant::Image:
						icon = KIcon(QIcon(QPixmap::fromImage(r.icon().value<QImage>())));
						break;
					default:
						// Shouldn't happen...
						break;
				}
				match.setIcon(icon);
				match.setText(r.label());
				match.setData(r.resource().resourceUri());
				match.setId(match.data().toUrl().toString());
				matches.append(match);
			}
		}
	}

	context.addMatches(context.query(), matches);
}

void NepomukRunner::performMatch(Plasma::RunnerContext& context)
{
}

void NepomukRunner::run(const Plasma::RunnerContext& context, const Plasma::QueryMatch& action)
{
	KRun::runCommand(QString("resourceinspector '%1'").arg(action.data().toUrl().toString()), NULL);
}

#include "nepomukrunner.moc"
