/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef NEPOMUKLINKWIDGET_H
#define NEPOMUKLINKWIDGET_H

#include <QtGui>
#include <QtGui/QSortFilterProxyModel>
#include <KLineEdit>
#include <KUrl>
#include <KMimeType>
#include <kio/job.h>

namespace Nepomuk {

class ResourceModel;
class RelationModel;
class AnnotationPlugin;

/**
 *
 *  \class LinkWidget linkwidget.h LinkWidget
 *  \author Adrien Bustany <madcat@mymadcat.com>
 *
 *  \brief A small widget that allows linking a given file to other resources on the desktop.
 *  The resources are provided by annotation plugins.
 */

class KDE_EXPORT LinkWidget : public KLineEdit
{
	Q_OBJECT

public:
	LinkWidget(QWidget* parent = 0);
	~LinkWidget();

	/**
	 * By default the results are shown in a popup menu. Using this function you can reparent
	 * that popup, to integrate it better in your interface.
	 * Call setPopupParent(NULL) to get back to the original popup.
	 */
	void setPopupParent(QWidget* parent);

	/**
	 * For historical reasons, the popup appears originally on the left of the text field.
	 * This functions allows you to change that.
	 */
	enum Position {
		North,
		East,
		South,
		West
	};
	void setPopupPosition(Position p);

	/**
	 * Returns a pointer to the results popup window
	 */
	QWidget* popup();

signals:
	void busy();
	void finished();

public Q_SLOTS:
	void setFile(const KUrl& url);

private:
	QListView* m_resourceView;
	ResourceModel* m_resources;
	RelationModel* m_relations;
	QSortFilterProxyModel* m_sortedRelations;
	KUrl m_currentFile;
	QUrl m_currentResourceUri;
	QUrl m_currentRelationUri;
	QShortcut* m_escapeShortcut;
	QList<AnnotationPlugin*> m_dataProviders;
	Position m_position;
	void setupAnnotationPlugins();
	void placeLists();

private Q_SLOTS:
	void textChanged(const QString& text);
	void itemActivated(const QModelIndex& index);
	void mimetype_cb(KIO::Job* job, const QString& type);
	void resetWidget();

protected:
	void closeEvent(QCloseEvent* event);
	void keyPressEvent(QKeyEvent* event);
	void keyReleaseEvent(QKeyEvent* event);
};

} // End namespace Nepomuk

#endif
