/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "relationmodel.h"
#include "annotationproperty.h"

using namespace Nepomuk;

RelationModel::RelationModel(QObject* parent) : QAbstractListModel(parent)
{
	m_mimetype = QString();
}

int RelationModel::rowCount(const QModelIndex& /*parent*/) const
{
	return m_properties.size();
}

QVariant RelationModel::data(const QModelIndex& index, int role) const
{
	if(index.row() >= m_properties.size()) return QVariant();
	switch(role) {
		case Qt::DisplayRole:
			return m_properties.at(index.row()).label();

		case Qt::DecorationRole:
			return m_properties.at(index.row()).icon();

		case RelationModel::Description:
			return m_properties.at(index.row()).description();

		case RelationModel::Uri:
			return m_properties.at(index.row()).property().uri();

		case RelationModel::Relevance:
			return m_properties.at(index.row()).relevance();

		default:
			return QVariant();
	}
}

AnnotationPlugin* RelationModel::plugin(const QModelIndex& index) const
{
	return m_properties.at(index.row()).parent();
}

void RelationModel::clear()
{
	beginRemoveRows(QModelIndex(), 0, m_properties.size()-1);
	m_properties.clear();
	endRemoveRows();
}

void RelationModel::fetchProperties(AnnotationPlugin* provider)
{
	QList<AnnotationProperty> properties = provider->getProperties(m_mimetype);
	if(properties.size() == 0) return;
	beginInsertRows(QModelIndex(), m_properties.size(), m_properties.size()+properties.size()-1);
	m_properties += properties;
	endInsertRows();
}

void RelationModel::setMimeType(const QString& type)
{
	m_mimetype = type;
}

#include "relationmodel.moc"
