/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "resourcedelegate.h"
#include "resourcemodel.h"

#define MARGIN 5

using namespace Nepomuk;

ResourceDelegate::ResourceDelegate(QObject* parent) : QStyledItemDelegate(parent)
{
}

QSize ResourceDelegate::sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const
{
	QFont titleFont = option.font;
	titleFont.setPointSize(titleFont.pointSize()+2);
	titleFont.setBold(true);
	QFontMetrics titleMetrics(titleFont);

	QFont descFont = option.font;
	QFontMetrics descMetrics(descFont);

	int iconSize = MARGIN + titleMetrics.height() + descMetrics.height();

	return QSize(3*MARGIN + iconSize + qMax(titleMetrics.width(index.data().toString()), descMetrics.width(index.data(Qt::UserRole).toString())), 2*MARGIN + iconSize);
}

void ResourceDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
{
	// Draw the standard background
	QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter);

	const int left = option.rect.left();
	const int top = option.rect.top();

	QColor foregroundColor = (option.state.testFlag(QStyle::State_Selected)) ? option.palette.color(QPalette::HighlightedText) : option.palette.color(QPalette::Text);
	
	QFont titleFont = option.font;
	titleFont.setPointSize(titleFont.pointSize()+2);
	titleFont.setBold(true);
	QFontMetrics titleMetrics(titleFont);

	QFont descFont = option.font;
	QFontMetrics descMetrics(descFont);

	int iconSize = MARGIN + titleMetrics.height() + descMetrics.height();
	QPixmap icon = index.data(Qt::DecorationRole).value<QPixmap>();
	icon = icon.isNull() ? icon : icon.scaled(iconSize, iconSize, Qt::KeepAspectRatio);

	painter->save();

	// Paint the icon
	painter->drawPixmap(left + MARGIN, top + MARGIN, icon);

	// Paint the title
	painter->setPen(foregroundColor);
	painter->setFont(titleFont);
	painter->drawText(left + 2*MARGIN + iconSize, top + MARGIN + titleMetrics.height(), index.data().toString());

	// Paint the description
	painter->setFont(descFont);
	painter->drawText(left + 2*MARGIN + iconSize, top + MARGIN + titleMetrics.height() + descMetrics.height(), index.data(ResourceModel::Description).toString());
	
	painter->restore();
}

#include "resourcedelegate.moc"
