/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef RESOURCEMODEL_H
#define RESOURCEMODEL_H

#include <QAbstractListModel>

namespace Nepomuk {

class AnnotationPlugin;
class AnnotationResource;

class ResourceModel : public QAbstractListModel
{
	Q_OBJECT

public:
	ResourceModel(QObject* parent = 0);
	int rowCount(const QModelIndex& parent = QModelIndex()) const;
	QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const;
	AnnotationPlugin* plugin(const QModelIndex& index) const;

	enum {
		Description = Qt::UserRole,
		Uri
	} Roles;

public Q_SLOTS:
	void setFilter(const QString& filter);
	void setAnnotationPlugins(const QList<AnnotationPlugin*>& providers);

private Q_SLOTS:
	void result_cb();

private:
	QList<AnnotationPlugin*> m_annotationPlugins;
	QList<AnnotationResource> m_resources;
	QMap<QString, QPixmap> m_icons;
};

} // End namespace Nepomuk

#endif
