/*
   Copyright (C) 2008 by Sebastian Trueg <trueg at kde.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "nsqd.h"
#include "sopranoforwardingcore.h"

#include <DNSSD/PublicService>
#include <DNSSD/ServiceBrowser>

#include <KDebug>
#include <KPluginFactory>
#include <KMessageBox>
#include <KLocale>


Nepomuk::SocialQueryDaemon::SocialQueryDaemon( QObject* parent, const QVariantList& )
    : Service( parent ),
      m_serverCore( 0 ),
      m_dnssdService( 0 )
{
    DNSSD::ServiceBrowser::State state = DNSSD::ServiceBrowser::isAvailable();

    if ( state == DNSSD::ServiceBrowser::Working ) {
        m_serverCore = new SopranoForwardingCore( mainModel(), this );

        // publish our own service
        // -------------------------
        m_serverCore->listen( 0 );

        // FIXME: try to choose a unique name
        m_dnssdService = new DNSSD::PublicService( "Nepomuk Social Query Service","_nepomuk._tcp", m_serverCore->serverPort() );
        QMap<QString, QByteArray> textData;
        textData.insert( "Description", "Browse my Nepomuk data store freely and without any restrictions." );
        m_dnssdService->setTextData( textData );
        if ( !m_dnssdService->publish() ) {
            kDebug() << "Failed to publish nsqd";
        }
    }
    else {
        // FIXME: better messages
        QString message;
        switch( state ) {
        case DNSSD::ServiceBrowser::Stopped:
            message = i18n("<p>The Zeroconf daemon is not running. See the Service Discovery Handbook"
                           " for more information.<br/>"
                           "Other users will not see this system when browsing"
                           " the network via zeroconf, but normal access will still work.</p>");
        case DNSSD::ServiceBrowser::Unsupported:
            message = i18n("<p>Zeroconf support is not available in this version of KDE."
                           " See the Service Discovery Handbook for more information.<br/>"
                           "Other users will not see this system when browsing"
                           " the network via zeroconf, but normal access will still work.</p>");
        default:
            message = i18n("<p>Unknown error with Zeroconf.<br/>"
                           "Other users will not see this system when browsing"
                           " the network via zeroconf, but normal access will still work.</p>");
        }
        kDebug() << message;
        KMessageBox::error( 0, message, i18n( "Unable to start Nepomuk Social Query Daemon" ) );
    }
}


Nepomuk::SocialQueryDaemon::~SocialQueryDaemon()
{
    delete m_dnssdService;
}


NEPOMUK_EXPORT_SERVICE( Nepomuk::SocialQueryDaemon, "nsqd")

#include "nsqd.moc"
