/*
   Copyright (C) 2008 by Sebastian Trueg <trueg at kde.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "sopranoforwardingcore.h"

#include <Soprano/Util/ReadOnlyModel>
#include <Soprano/Util/DummyModel>
#include <Soprano/Backend>
#include <Soprano/StorageModel>
#include <Soprano/PluginManager>
#include <Soprano/LiteralValue>
#include <Soprano/Vocabulary/RDFS>

#include <KUser>
#include <KDebug>


SopranoForwardingCore::SopranoForwardingCore( Soprano::Model* mainModel, QObject* parent )
    : ServerCore( parent )
{
    if ( const Soprano::Backend* backend
         = Soprano::PluginManager::instance()->discoverBackendByFeatures( Soprano::BackendFeatureStorageMemory ) ) {
        m_personalDataModel = backend->createModel();
    }
    else {
        kDebug() << "Unable to create personal data model!";
        m_personalDataModel = new Soprano::Util::DummyModel();
    }

    // add some basic personal data about the Nepomuk desktop
    // FIXME: use a proper ontology generated by soprano's onto tool
    KUser user;
    QString userName = user.property( KUser::FullName ).toString();
    if ( userName.isEmpty() ) {
        userName = user.loginName();
    }
    m_personalDataModel->addStatement( QUrl( "http://nepomuk.kde.org/nsqd/onto#Instance" ),
                                       Soprano::Vocabulary::RDFS::label(),
                                       Soprano::LiteralValue( userName ) );

    Soprano::Util::ReadOnlyModel* roModel = new Soprano::Util::ReadOnlyModel( m_personalDataModel );
    m_personalDataModel->setParent( roModel ); // memory management
    m_models.insert( "nsq-personal-data", roModel );

    roModel = new Soprano::Util::ReadOnlyModel( mainModel );
    m_models.insert( "main", roModel );
}


SopranoForwardingCore::~SopranoForwardingCore()
{
    qDeleteAll( m_models );
}


Soprano::Model* SopranoForwardingCore::model( const QString& name )
{
    if ( m_models.contains( name ) ) {
        return m_models[name];
    }
    else {
        kDebug() << "Unsupported model:" << name;
        return 0;
    }
}


void SopranoForwardingCore::removeModel( const QString& )
{
    // do nothing, remote connection should at least not delete everything
}


QStringList SopranoForwardingCore::allModels() const
{
    return m_models.keys();
}

#include "sopranoforwardingcore.moc"
