/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "imagemarquee.h"
#include "fancyrect.h"

using namespace Nepomuk;

ImageMarquee::ImageMarquee(QObject *parent) : QGraphicsScene(parent)
{
	m_rectPen.setColor(Qt::white);
	m_picture = new PictureFrame(this);
	addItem(m_picture);
	
	connect(m_picture, SIGNAL(newMarquee(Marquee*)), this, SLOT(addMarquee(Marquee*)));
	connect(m_picture, SIGNAL(newMarquee(Marquee*)), this, SIGNAL(newMarquee(Marquee*)));
}

// Used when loading existing marquees from Nepomuk
Marquee* ImageMarquee::addExistingMarquee(qreal x, qreal y, qreal w, qreal h, const QString& id)
{
	FancyRect *item = new FancyRect();
	QRectF rect = QRectF(0, 0, w, h);
	item->setPos(x, y);
	item->setRect(rect);
	Marquee* m = new Marquee(item);
	m->setId(id);
	addMarquee(m);
	return m;
}

void ImageMarquee::loadPicture(const QString &path)
{
	m_picture->setPos(0, 0);
	m_picture->loadPicture(path);
	setSceneRect(m_picture->boundingRect());
}

void ImageMarquee::addMarquee(Marquee *m) {
	m_regions.append(m);
	addItem(m);
	connect(m, SIGNAL(selected(Marquee*)), this, SLOT(deselectOtherMarquees(Marquee*)));
	connect(m, SIGNAL(selected(Marquee*)), this, SIGNAL(marqueeSelected(Marquee*)));
	deselectOtherMarquees(m);
}

void ImageMarquee::deselectOtherMarquees(Marquee *m) {
	foreach(QGraphicsItem *i, selectedItems()) {
		i->setSelected(false);
	}
	if(m) // Allows passing m = NULL to deselect all marquees
		m->setSelected(true);
}

void ImageMarquee::matrixChanged(const QMatrix& matrix)
{
	QMatrix inverted = matrix.inverted();
	foreach (Marquee* m, m_regions) {
		m->setLabelMatrix(inverted);
	}
}

#include "imagemarquee.moc"
