/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef IMAGEMARQUEE_H
#define IMAGEMARQUEE_H

#include <QtGui>

#include "marquee.h"
#include "pictureframe.h"

namespace Nepomuk {

class ImageMarquee : public QGraphicsScene
{
	Q_OBJECT
	
public:
	ImageMarquee(QObject *parent = 0);
	Marquee* addExistingMarquee(qreal x, qreal y, qreal w, qreal h, const QString& id);
	
public Q_SLOTS:
	void loadPicture(const QString &path);
	void deselectOtherMarquees(Marquee *m); // Used to prevent multiple selections
	void matrixChanged(const QMatrix& matrix); // Called when the view changes its matrix, used to resize labels

signals:
	void newMarquee(Marquee*);
	void marqueeSelected(Marquee*);

private Q_SLOTS:
	void addMarquee(Marquee*);

private:
	PictureFrame*	m_picture; // The item holding the picture
	QPen			m_rectPen; // The pen used to draw the frames
	QList<Marquee*>	m_regions; // The list of drawed rects

protected:
};

} // End namespace Nepomuk

#endif
