/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "pictureframe.h"
#include "fancyrect.h"

using namespace Nepomuk;

PictureFrame::PictureFrame(QObject *parent) : QObject(parent), QGraphicsPixmapItem(0){
	m_currentRect = NULL;
	m_drawing = false;

	m_rectPen.setColor(Qt::white);
	setZValue(-1); // Ensure we stay in the background
}

void PictureFrame::loadPicture(const QString &path)
{
	setPixmap(QPixmap(path));
}

void PictureFrame::mousePressEvent(QGraphicsSceneMouseEvent *e)
{
	m_x1 = e->scenePos().x();
	m_y1 = e->scenePos().y();
	m_currentRect = new FancyRect(m_x1, m_y1, 1, 1);
	scene()->addItem(m_currentRect);
	m_currentRect->setPen(m_rectPen);
	m_drawing = true;

}

void PictureFrame::mouseMoveEvent(QGraphicsSceneMouseEvent *e)
{
	if (!m_drawing) return;
	m_x2 = e->scenePos().x();
	m_y2 = e->scenePos().y();
	QRectF rect(0, 0, m_x2-m_x1, m_y2-m_y1);
	m_currentRect->setRect(rect);
	m_currentRect->setPos(m_x1, m_y1);
}

void PictureFrame::mouseReleaseEvent(QGraphicsSceneMouseEvent * /*e*/)
{
	if (!m_drawing) return;
	if (m_currentRect->rect().width() > 1 && m_currentRect->rect().height() > 1) {
		emit newMarquee(new Marquee(m_currentRect));
	} else {
		delete(m_currentRect);
	}
	m_drawing = false;

}

#include "pictureframe.moc"

