/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include "filtermodel.h"
#include "linkedpeoplemodel.h"
#include "item.h"

using namespace Nepomuk;

FilterModel::FilterModel(QObject *parent) : QSortFilterProxyModel(parent)
{
	m_maskModel = NULL;
}

bool FilterModel::filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const
{
	Item *item = static_cast<Item*>(sourceModel()->index(sourceRow, 0, sourceParent).internalPointer());

	// Filter with the mask if we have one
	if (m_maskModel && m_maskModel->containsId(item->id)) {
		return false;
	}

	// The row is accepted if :
	// The regexp matches the name of the person
	// The regexp matches the name of the group
	// The regexp matches a person in the group
	if (item->name.contains(filterRegExp())) return true;
	foreach(Item *child, item->children)
		if (child->name.contains(filterRegExp())) return true;
	if (item->parent && item->parent->name.contains(filterRegExp())) return true;
	return false; // Should never be reached
}

void FilterModel::setMaskModel(LinkedPeopleModel *mask)
{
	m_maskModel = mask;
	connect(m_maskModel, SIGNAL(changed()), this, SLOT(resetModel()));
}

void FilterModel::resetModel()
{
	reset();
}

#include "filtermodel.moc"
