/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#include <nepomuk/resourcemanager.h> // Needed for uri generation
#include <klocalizedstring.h>

#include "otherpersondialog.h"
#include "peoplemodel.h"

#include <soprano/soprano.h>

#define TEXT_NOTINANYGROUP i18n("Not in any group")
#define TEXT_REFRESHINGGROUPS i18n("Refreshing groups...")

Nepomuk::OtherPersonDialog::OtherPersonDialog(QWidget *parent) : QDialog(parent), Ui::OtherPersonDialog()
{
	setupUi(this);
	setWindowTitle(i18n("Add a person into Nepomuk"));

	m_nepomuk = NepomukProxy::getInstance();
	connect(m_nepomuk, SIGNAL(groups(const QList<Soprano::BindingSet>&)), this, SLOT(groupList(const QList<Soprano::BindingSet>&)));
	m_nepomuk->getGroups();

	m_groupsBox->setEditText(TEXT_REFRESHINGGROUPS);
	m_statusLabel->setVisible(false);

	// Reset the dialog when closed (OK or Cancel)
	connect(this, SIGNAL(finished(int)), this, SLOT(resetDialog()));

	connect(m_buttonBox, SIGNAL(accepted()), this, SLOT(addPerson()));
}

void Nepomuk::OtherPersonDialog::groupList(const QList<Soprano::BindingSet>& bindings)
{
	m_groupsBox->clear();
	m_groupsBox->addItem(TEXT_NOTINANYGROUP, QString(""));
	foreach(Soprano::BindingSet set, bindings) {
		m_groupsBox->addItem(set["name"].literal().toString(), set["gid"].uri().toString());
	}
	m_groupsBox->setEnabled(true);
}

void Nepomuk::OtherPersonDialog::resetDialog()
{
	m_fullnameLabel->clear();
	m_fullnameLabel->setEnabled(true);
	m_groupsBox->setCurrentIndex(0);
	m_groupsBox->setEnabled(true);
	m_buttonBox->setEnabled(true);
	m_statusLabel->setVisible(false);
}

void Nepomuk::OtherPersonDialog::addPerson()
{
	if (m_groupsBox->currentText() == TEXT_REFRESHINGGROUPS) {
		return; // Could happen if the user clicks ok when the groups are not refreshed yet
	}

	if (m_fullnameLabel->text().isEmpty()) {
	   return;
	}

	// Disable the controls while the operation is pending
	m_buttonBox->setEnabled(false);
	m_fullnameLabel->setEnabled(false);
	m_groupsBox->setEnabled(false);
	m_statusLabel->setText(i18n("Adding person..."));
	m_statusLabel->setVisible(true);

	// We have at least one operation to do : add the person
	m_completion = 1;

	// Be notified when our queries finish
	connect(m_nepomuk, SIGNAL(contactAdded()), this, SLOT(queryFinished()));
	connect(m_nepomuk, SIGNAL(groupAdded()), this, SLOT(queryFinished()));

	// Add a new group if needed
	QString groupId = m_groupsBox->itemData(m_groupsBox->currentIndex()).toString();
	if ((groupId == QString()) && (m_groupsBox->currentText() != TEXT_NOTINANYGROUP) && !(m_groupsBox->currentText().isEmpty())) {
		m_completion++;
		groupId = m_nepomuk->addGroup(m_groupsBox->currentText());
		m_groupsBox->setItemData(m_groupsBox->currentIndex(), groupId);

		// Reload the groups
		m_groupsBox->setEnabled(false);
		m_groupsBox->setEditText(TEXT_REFRESHINGGROUPS);
		m_nepomuk->getGroups();
	}

	if (groupId == QString("")) {
		m_nepomuk->addContact(m_fullnameLabel->text());
	} else {
		m_nepomuk->addContact(m_fullnameLabel->text(), groupId);
	}
}

void Nepomuk::OtherPersonDialog::queryFinished()
{
	m_completion--;

	if (m_completion == 0) { // If we've no more transactions to wait for, close the dialog
		disconnect(this, SLOT(queryFinished()));
		accept(); // Will take care of resetting the dialog to its initial state
	}
}

#include "otherpersondialog.moc"
