/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2007 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
 */

#include "nepomukbibtexresourceguiitem.h"
#include "swrc.h"
#include "nco.h"

#include <KIcon>
#include <KPluginFactory>
#include <KPluginLoader>
#include <KLocale>

#include <nepomuk/resource.h>
#include <nepomuk/variant.h>


K_PLUGIN_FACTORY(BibtexResourceGuiItemFactory, registerPlugin<Nepomuk::BibtexResourceGuiItem>();)
K_EXPORT_PLUGIN(BibtexResourceGuiItemFactory("nepomuk_bibtexresourceguiitem"))


Nepomuk::BibtexResourceGuiItem::BibtexResourceGuiItem( QObject* parent, const QList<QVariant>& )
    : GenericResourceGuiItem( parent )
{
}


Nepomuk::BibtexResourceGuiItem::~BibtexResourceGuiItem()
{
}


QString Nepomuk::BibtexResourceGuiItem::genericLabel( const Resource& resource )
{
    QString s = resource.property( Nepomuk::Vocabulary::Ontoware::SWRC::title() ).toString().replace( QRegExp( "\\s" ), " " ).simplified();
    return s.isEmpty() ? resource.genericLabel() : s;
}


QString Nepomuk::BibtexResourceGuiItem::genericDescription( const Resource& resource )
{
    QString s;
    QString year = resource.property( Nepomuk::Vocabulary::Ontoware::SWRC::year() ).toString();

    if ( resource.hasProperty( Nepomuk::Vocabulary::Ontoware::SWRC::creator() ) ) {
        QList<Resource> authors = resource.property( Nepomuk::Vocabulary::Ontoware::SWRC::creator() ).toResourceList();
        QStringList names;
        foreach( Resource author, authors ) {
            names += author.property( Nepomuk::Vocabulary::NCO::fullname() ).toString();
        }
        QString name = names.join( ", " );
        if ( year.isEmpty() ) {
            s += i18n( "written by %1", name );
        }
        else {
            s += i18n( "written %1 by %2", year, name );
        }
    }
    if ( resource.hasProperty( Nepomuk::Vocabulary::Ontoware::SWRC::abstract() ) ) {
        s += "\n" + resource.property( Nepomuk::Vocabulary::Ontoware::SWRC::abstract() ).toString();
    }
    return s;
}


QPixmap Nepomuk::BibtexResourceGuiItem::genericPixmap( const Resource& resource, const QSize& size )
{
    Q_UNUSED( resource );
    // FIXME: use a better icon
    return KIcon( "accessories-dictionary" ).pixmap( size );
}

#include "nepomukbibtexresourceguiitem.moc"
