#include "actionbutton.h"

#define ICONSIZE 32.
#define SQRT2 1.4
#define MARGIN 5.

#define RADIUS ICONSIZE/SQRT2 + MARGIN
#define STROKEWIDTH 0.

#define DEFAULTBLUE 0, 177, 228

ActionButton::ActionButton(const QIcon& icon, const QString& label, QGraphicsItem* parent) : QObject(), QGraphicsItem(parent), m_label(label)
{
	m_icon = icon.pixmap(ICONSIZE, ICONSIZE);

	m_pen.setColor(QColor(DEFAULTBLUE));
	m_pen.setWidthF(STROKEWIDTH);

	m_brush.setStyle(Qt::SolidPattern);
	m_brush.setColor(QColor(DEFAULTBLUE));

	// Be notified when the mouse is on us
	setAcceptHoverEvents(true);

	// We don't want to be resized
	setFlag(QGraphicsItem::ItemIgnoresTransformations);
}

ActionButton::~ActionButton()
{
}

void ActionButton::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget)
{
	painter->save();

	painter->setPen(m_pen);
	painter->setBrush(m_brush);

	painter->drawEllipse(-RADIUS, -RADIUS, 2*RADIUS, 2*RADIUS);

	painter->drawPixmap(-ICONSIZE/4, -ICONSIZE/4, m_icon);

	painter->restore();
}

QRectF ActionButton::boundingRect() const
{
	return QRectF(-RADIUS-STROKEWIDTH, -RADIUS-STROKEWIDTH, 2*(RADIUS+STROKEWIDTH), 2*(RADIUS+STROKEWIDTH));
}

QString ActionButton::label()
{
	return m_label;
}

void ActionButton::setColor(const QColor& color)
{
	m_pen.setColor(color);
	m_brush.setColor(color);
}

float ActionButton::radius()
{
	return RADIUS;
}

float ActionButton::margin()
{
	return MARGIN;
}

void ActionButton::mousePressEvent(QGraphicsSceneMouseEvent* event)
{
	event->accept();
}

void ActionButton::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
{
	if(event->button() == Qt::LeftButton) {
		emit clicked();
	}
}

void ActionButton::hoverEnterEvent(QGraphicsSceneHoverEvent* event)
{
	emit mouseOver();
}

void ActionButton::hoverLeaveEvent(QGraphicsSceneHoverEvent* event)
{
	emit mouseOut();
}
