#ifndef PLANET_H
#define PLANET_H

#include <QtGui>
#include <KSharedPtr>
#include <KService>
#include "annotationresource.h"
#include "actionbutton.h"

class Planet : public QObject, public QGraphicsItem
{

	Q_OBJECT

public:
	Planet(const Nepomuk::AnnotationResource& resource);
	~Planet();

	void paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0);
	QRectF boundingRect() const;

	// Override setPos to animate the movements
	void setPos(const QPointF& newPos);
	void setPos(qreal x, qreal y);

	void setPosImmediate(const QPointF& newPos);
	void setPosImmediate(qreal x, qreal y);

	bool visible() const;

	// Changes the stroke color to provide a visual feeback for selected resources
	void setActive(bool active);

	/**
	 * Set the possible actions for this resource.
	 * \a actions is a QList of KSharedPtr<KService>
	 */
	void setActions(const QList<KSharedPtr<KService> >& actions);

	/**
	 * Shows or hide the action buttons above the resource planet
	 */
	void showActions(bool show);

	// Allow access to constants in planet.cpp
	static float radius();
	static float margin();

	const Nepomuk::AnnotationResource& resource();

Q_SIGNALS:
	void moved(const QPointF& newPos);
	void clicked();
	void visibilityChanged();
	void actionText(const QString& text);

public Q_SLOTS:
	void show();
	void hide();

private:
	Nepomuk::AnnotationResource m_resource;
	// Caches the Nepomuk::AnnotationResource icon
	QPixmap m_icon;

	QPen m_planetPen;
	QBrush m_planetBrush;

	// Weither to show or not the action buttons
	bool m_showActions;

	// Animation used when moving the item
	QGraphicsItemAnimation* m_moveAnimation;

	// Animation used when removing the item
	QGraphicsItemAnimation* m_removeAnimation;

	// Timeline used to show/hide the planet
	QTimeLine* m_showHideTimeline;
	qreal m_alpha;
	bool m_visible;

	// All the actions buttons mapped to their exec commands
	QHash<ActionButton*, QString> m_execCommands;

	void paintActions(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget = 0);

	// Place the action buttons above the planet
	void placeActionButtons();

	// True if the resource is selected
	bool m_active;

private Q_SLOTS:
	void actionButtonClicked();
	void setAlpha(int value); // Value belongs to [0-100]
	void action_mouseOver();
	void action_mouseOut();

protected:
	QVariant itemChange(GraphicsItemChange change, const QVariant& value);
	void mousePressEvent(QGraphicsSceneMouseEvent* event);
	void mouseReleaseEvent(QGraphicsSceneMouseEvent* event);
};

#endif
