#ifndef RESOURCEINSPECTOR_H
#define RESOURCEINSPECTOR_H

#include <QtGui>
#include <KSharedPtr>
#include <KService>
#include "annotationresource.h"

namespace Nepomuk {
	class AnnotationPlugin;
}

class Planet;
class ActionButton;
class InfoPanel;

class ResourceInspector : public QGraphicsView
{
	Q_OBJECT

public:
	ResourceInspector(QWidget* parent = 0);
	~ResourceInspector();

	void setResource(const QUrl& resourceUri);

private:
	QGraphicsScene* m_scene;
	QPen m_linkPen;

	QList<Planet*> m_satellites;
	QHash<Planet*, QGraphicsLineItem*> m_satelliteLinks;

	float systemRadius() const; // Returns the distance between the central planet and the satellites
	void placeSatellites(); // Used to spread the related resources around the main resource

	QUrl m_currentUri;

	Planet* m_centralPlanet;

	// Defines the center of the scene, excluding GUI buttons (filters + search field)
	QPointF m_sceneCenter;

	QMap<QString, KSharedPtr<KService> > m_actions; // Caches the actions we can use to "run" the rdf resources

	// Used to keep track of the different datatypes exposed on the scene, to show relevant sorting actions
	// This QMap maps the ActionButton* to its plugin
	ActionButton* m_showAllButton;
	QMap<ActionButton*, Nepomuk::AnnotationPlugin*> m_filterPlugins;
	Nepomuk::AnnotationPlugin* m_currentFilterPlugin;
	void showFilterButtons(bool show = true);

	// Status text at the top of the scene
	QBrush m_textBrush;
	QGraphicsSimpleTextItem* m_statusMessage;

	// Search field in the bottom right
	QGraphicsProxyWidget* m_searchFieldProxy;

	// Info panel on the right of the screen
	InfoPanel* m_infoPanel;


private Q_SLOTS:
	// Catches the data for the main resource
	void result_cb();

	// Catches the data for the related resources
	void relatedResult_cb();

	// Updates the link between the sender and the main resource
	void updateLink(const QPointF& newPos);
	void updateLinkVisibility(); // Hide the link when a planet gets hidden

	void satellite_clicked();

	void actionButton_hover(const QString& message);
	void filterButton_hover();
	void resetStatusMessage();

	void setFilterPlugin(); // Invoked when clicking on a filter ActionButton, sets m_currentFilterPlugin
	void filterPlanets();

	void escapeKey_cb(); // Clears the text or closes the window

protected:
	void resizeEvent(QResizeEvent* event);
	void wheelEvent(QWheelEvent* event);
};

#endif
